@@ -1,4 +1,4 @@
-from .run import main
+from cqh_file_watcher.run import main
 
 
 if __name__ == "__main__":
